@@ -4,7 +4,7 @@
 * acp_board [Belarusian]
 *
 * @package language
-* @version $Id: board.php,v 1.101 2007/11/03 20:29:39 acydburn Exp $
+* @version $Id$
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
@@ -40,7 +40,7 @@ $lang = array_merge($lang, array(
 	'ACP_BOARD_SETTINGS_EXPLAIN'	=> 'Тут вы можаце ўсталяваць агульныя параметры канферэнцыі, даць ёй імя і апісанне, а таксама паказаць гадзінны пояс і мова, якія будуць выкарыстоўвацца па змаўчанні.',
 	'CUSTOM_DATEFORMAT'				=> 'Іншы…',
 	'DEFAULT_DATE_FORMAT'			=> 'Фармат даты',
-	'DEFAULT_DATE_FORMAT_EXPLAIN'	=> 'Сінтаксіс ідэнтычны функцыі <code><a href="http://www.php.net/date">date</code></a> мовы PHP.',
+	'DEFAULT_DATE_FORMAT_EXPLAIN'	=> 'Сінтаксіс ідэнтычны функцыі <code>date</code> мовы PHP.',
 	'DEFAULT_LANGUAGE'				=> 'Мова канферэнцыі па змаўчанні',
 	'DEFAULT_STYLE'					=> 'Стыль канферэнцыі па змаўчанні',
 	'DISABLE_BOARD'					=> 'Адключыць канферэнцыю',
@@ -547,4 +547,4 @@ $lang = array_merge($lang, array(
 	'JAB_USERNAME_EXPLAIN'		=> 'Увядзіце імя або існуючы JID (ідэнтыфікатар) зарэгістраванага карыстальніка. Праверка імя праводзіцца не будзе. Калі паказана толькі імя, то ваш JID (ідэнтыфікатар) будзе складзены з гэтага імя і паказанага вышэй імя сервера. У адваротным выпадку ўкажыце існуючы JID (ідэнтыфікатар), напрыклад, user@jabber.org.',
 ));
 
-?>
\ No newline at end of file
+?>
