@@ -266,7 +266,7 @@ $lang = array_merge($lang, array(
 	'PARSE_SMILIES'						=> 'Дазволіць смайлікі',
 	'PARSE_URLS'						=> 'Дазволіць спасылкі',
 	'PERMISSIONS_TRANSFERRED'			=> 'Перадача праў доступу',
-	'PERMISSIONS_TRANSFERRED_EXPLAIN'	=> 'У цяперашні час вы выкарыстоўваеце права карыстальніка% 1$s. Вы можаце праглядаць канферэнцыю з правамі дадзенага карыстальніка, але не будзеце мець доступу ў панэль адміністравання, паколькі правы адміністратара не перададзены. Вы можаце <a href="%2$s"><strong>аднавіць свае правы</strong></a> ў любы час.',
+	'PERMISSIONS_TRANSFERRED_EXPLAIN'	=> 'У цяперашні час вы выкарыстоўваеце права карыстальніка %1$s. Вы можаце праглядаць канферэнцыю з правамі дадзенага карыстальніка, але не будзеце мець доступу ў панэль адміністравання, паколькі правы адміністратара не перададзены. Вы можаце <a href="%2$s"><strong>аднавіць свае правы</strong></a> ў любы час.',
 	'PROCEED_TO_ACP'					=> '%sПерайсці ў панэль адміністравання%s',
 
 	'REMIND'							=> 'Нагадаць',
@@ -421,7 +421,7 @@ $lang = array_merge($lang, array(
 
 // Send statistics page
 $lang = array_merge($lang, array(
-	'EXPLAIN_SEND_STATISTICS'	=> 'Дашліце нам інфармацыю аб вашым сэрвэры і канфігурацыі phpBB для статыстычнага аналізу. Уся інфармацыя, якая магла б ідэнтыфікаваць вас ці ваш сайт, сцёртая - дадзеныя цалкам <strong>ананімныя</ strong>. Грунтуючыся на прадастаўленай вамі інфармацыі, мы будзем прымаць рашэнні аб функцыянальнасці будучых версій phpBB. Статыстычныя дадзеныя прадстаўляюцца публічна. Мы таксама выкарыстоўваем гэтыя дадзеныя сумесна з праектам PHP (мова праграмавання, на якім напісаны phpBB).',
+	'EXPLAIN_SEND_STATISTICS'	=> 'Дашліце нам інфармацыю аб вашым сэрвэры і канфігурацыі phpBB для статыстычнага аналізу. Уся інфармацыя, якая магла б ідэнтыфікаваць вас ці ваш сайт, сцёртая - дадзеныя цалкам <strong>ананімныя</strong>. Грунтуючыся на прадастаўленай вамі інфармацыі, мы будзем прымаць рашэнні аб функцыянальнасці будучых версій phpBB. Статыстычныя дадзеныя прадстаўляюцца публічна. Мы таксама выкарыстоўваем гэтыя дадзеныя сумесна з праектам PHP (мова праграмавання, на якой напісаны phpBB).',
 	'EXPLAIN_SHOW_STATISTICS'	=> 'Выкарыстоўваючы кнопку ніжэй, вы можаце праглядзець усе пераменныя, якія будуць перададзены.',
 	'DONT_SEND_STATISTICS'		=> 'Пераход на галоўную старонку панэлі адміністравання',
 	'GO_ACP_MAIN'				=> 'Пераход на галоўную старонку панэлі адміністравання',
@@ -524,7 +524,7 @@ $lang = array_merge($lang, array(
 	'LOG_LOCK'					=> '<strong>Зачыненая тэма</strong><br />» %s',
 	'LOG_LOCK_POST'				=> '<strong>Заблакавана паведамленне</strong><br />» %s',
 	'LOG_MERGE'					=> '<strong>Аб\'яднаныя паведамленні</strong> у тэму<br />» %s',
-	'LOG_MOVE'					=> '<strong>Перамешчаная тэма</strong><br />» з %s',
+	'LOG_MOVE'					=> '<strong>Перамешчана тэма</strong><br />» з %1$s у %2$s',
 	'LOG_PM_REPORT_CLOSED'		=> '<strong>Зачыненая скарга на асабістае паведамленне</strong><br />» %s',
 	'LOG_PM_REPORT_DELETED'		=> '<strong>Выдаленая скарга на асабістае паведамленне</strong><br />» %s',
 	'LOG_POST_APPROVED'			=> '<strong>Ухвала паведамлення</strong><br />» %s',
@@ -572,17 +572,17 @@ $lang = array_merge($lang, array(
 	'LOG_FORUM_MOVE_UP'						=> '<strong>Перамешчаны форум</strong> %1$s <strong>над</strong> %2$s',
 	'LOG_FORUM_SYNC'						=> '<strong>Сінхранізаваны форум</strong><br />» %s',
 
-	'LOG_GENERAL_ERROR'	=> '<strong>Адбылася агульная памылка:</strong> %1$s <br />» %2$s',
+	'LOG_GENERAL_ERROR'	=> '<strong>Адбылася агульная памылка:</strong>: %1$s <br />» %2$s',
 
-	'LOG_GROUP_CREATED'		=> '<strong>Створаная група карыстальнікаў</strong><br />» %s',
-	'LOG_GROUP_DEFAULTS'	=> '<strong>Прызначаная групай па змаўчанні для карыстальнікаў</strong><br />» %s',
-	'LOG_GROUP_DELETE'		=> '<strong>Выдаленая група</strong><br />» %s',
-	'LOG_GROUP_DEMOTED'		=> '<strong>Знятыя лідэры ў групе</strong> %1$s<br />» %2$s',
-	'LOG_GROUP_PROMOTED'	=> '<strong>Прызначаныя лідэры ў групе</strong> %1$s<br />» %2$s',
-	'LOG_GROUP_REMOVE'		=> '<strong>Выдаленыя карыстальнікі з групы</strong> %1$s<br />» %2$s',
-	'LOG_GROUP_UPDATED'		=> '<strong>Абноўленая інфармацыя аб групе</strong><br />» %s',
-	'LOG_MODS_ADDED'		=> '<strong>Дададзеныя новыя лідэры ў групу</strong> %1$s<br />» %2$s',
-	'LOG_USERS_ADDED'		=> '<strong>Дададзеныя карыстальнікі ў групу</strong> %1$s<br />» %2$s',
+	'LOG_GROUP_CREATED'		=> '<strong>Створана новая група карыстальнікаў</strong><br />» %s',
+	'LOG_GROUP_DEFAULTS'	=> '<strong>Група “%1$s” прызначана групай па змаўчанні для карыстальнікаў</strong><br />» %2$s',
+	'LOG_GROUP_DELETE'		=> '<strong>Выдалена група</strong><br />» %s',
+	'LOG_GROUP_DEMOTED'		=> '<strong>Зняты лідэры ў групе</strong> %1$s<br />» %2$s',
+	'LOG_GROUP_PROMOTED'	=> '<strong>Прызначаны лідэры ў групе</strong> %1$s<br />» %2$s',
+	'LOG_GROUP_REMOVE'		=> '<strong>Выдалены карыстальнікі з групы</strong> %1$s<br />» %2$s',
+	'LOG_GROUP_UPDATED'		=> '<strong>Абноўлена інфармацыя аб групе</strong><br />» %s',
+	'LOG_MODS_ADDED'		=> '<strong>Дададзены новыя лідэры ў групу</strong> %1$s<br />» %2$s',
+	'LOG_USERS_ADDED'		=> '<strong>Дададзены карыстальнікі ў групу</strong> %1$s<br />» %2$s',
 	'LOG_USERS_APPROVED'	=> '<strong>Ухваленыя кандыдаты ў групу</strong> %1$s<br />» %2$s',
 	'LOG_USERS_PENDING'		=> '<strong>Карыстальнікі запыталі ўступлення ў групу «%1$s» і чакаюць адабрэння</strong><br />» %2$s',
 
@@ -657,6 +657,7 @@ $lang = array_merge($lang, array(
 	'LOG_PURGE_CACHE'			=> '<strong>Ачыстка кэша</strong>',
 	'LOG_PURGE_SESSIONS'		=> '<strong>Ачыстка сесій</strong>',
 
+
 	'LOG_RANK_ADDED'		=> '<strong>Дададзена званне</strong><br />» %s',
 	'LOG_RANK_REMOVED'		=> '<strong>Выдаленае званне</strong><br />» %s',
 	'LOG_RANK_UPDATED'		=> '<strong>Абноўленае званне</strong><br />» %s',
@@ -666,11 +667,11 @@ $lang = array_merge($lang, array(
 	'LOG_REASON_UPDATED'	=> '<strong>Абноўленая чыннік скаргі/адхіленні</strong><br />» %s',
 
 	'LOG_REFERER_INVALID'		=> '<strong>Памылка праверкі рэферэра</strong><br />В»Рэферэр быў "<em>%1$s</em>". Запыт быў адхілены, і сесія была знішчана.',
-	'LOG_RESET_DATE'			=> '<strong>Скінутая дата запуску канферэнцыі</strong>',
+	'LOG_RESET_DATE'			=> '<strong>Скінута дата запуску канферэнцыі</strong>',
 	'LOG_RESET_ONLINE'			=> '<strong>Скінуты рэкорд наведвальнасці</strong>',
-	'LOG_RESYNC_POSTCOUNTS'		=> '<strong>Сінхранізаваныя лічыльнікі паведамленняў карыстальнікаў</strong>',
-	'LOG_RESYNC_POST_MARKING'	=> '<strong>Сінхранізаваныя свае тэмы</strong>',
-	'LOG_RESYNC_STATS'			=> '<strong>Сінхранізаваная статыстыка паведамленняў, тэм і карыстальнікаў</strong>',
+	'LOG_RESYNC_POSTCOUNTS'		=> '<strong>Сінхранізаваны лічыльнікі паведамленняў карыстальнікаў</strong>',
+	'LOG_RESYNC_POST_MARKING'	=> '<strong>Сінхранізаваны свае тэмы</strong>',
+	'LOG_RESYNC_STATS'			=> '<strong>Сінхранізавана статыстыка паведамленняў, тэм і карыстальнікаў</strong>',
 
 	'LOG_SEARCH_INDEX_CREATED'	=> '<strong>Створаныя пошукавыя індэксы для</strong><br />» %s',
 	'LOG_SEARCH_INDEX_REMOVED'	=> '<strong>Выдаленыя пошукавыя індэксы для</strong><br />» %s',
@@ -688,14 +689,14 @@ $lang = array_merge($lang, array(
 	'LOG_TEMPLATE_EXPORT'			=> '<strong>Экспартаваны шаблон</strong><br />» %s',
 	'LOG_TEMPLATE_REFRESHED'		=> '<strong>Абноўлены шаблон</strong><br />» %s',
 
-	'LOG_THEME_ADD_DB'			=> '<strong>Дададзеная тэма ў базу дадзеных</strong><br />» %s',
-	'LOG_THEME_ADD_FS'			=> '<strong>Дададзеная тэма на сервер</strong><br />» %s',
-	'LOG_THEME_DELETE'			=> '<strong>Выдаленая тэма</strong><br />» %s',
-	'LOG_THEME_EDIT_DETAILS'	=> '<strong>Змененая інфармацыя аб тэме</strong><br />» %s',
-	'LOG_THEME_EDIT'			=> '<strong>Змененая тэма <em>%1$s</em></strong><br />» Зменены клас <em>%2$s</em>',
+	'LOG_THEME_ADD_DB'			=> '<strong>Дададзена тэма ў базу дадзеных</strong><br />» %s',
+	'LOG_THEME_ADD_FS'			=> '<strong>Дададзена тэма на сервер</strong><br />» %s',
+	'LOG_THEME_DELETE'			=> '<strong>Выдалена тэма</strong><br />» %s',
+	'LOG_THEME_EDIT_DETAILS'	=> '<strong>Зменена інфармацыя аб тэме</strong><br />» %s',
+	'LOG_THEME_EDIT'			=> '<strong>Зменена тэма <em>%1$s</em></strong>',
 	'LOG_THEME_EDIT_FILE'		=> '<strong>Змена тэмы афармлення стылю <em>%1$s</em></strong><br />» Зменены файл <em>%2$s</em>',
-	'LOG_THEME_EXPORT'			=> '<strong>Экспартаваная тэма</strong><br />» %s',
-	'LOG_THEME_REFRESHED'		=> '<strong>Абноўленая тэма</strong><br />» %s',
+	'LOG_THEME_EXPORT'			=> '<strong>Экспартавана тэма</strong><br />» %s',
+	'LOG_THEME_REFRESHED'		=> '<strong>Абноўлена тэма</strong><br />» %s',
 
 	'LOG_UPDATE_DATABASE'	=> '<strong>Абноўленая база дадзеных з версіі %1$s да версіі %2$s</strong>',
 	'LOG_UPDATE_PHPBB'		=> '<strong>Абноўлены phpBB з версіі %1$s да версіі %2$s</strong>',
