@@ -4,7 +4,7 @@
 * common [Belarusian]
 *
 * @package language
-* @version $Id: common.php,v 1.195 2007/11/06 14:55:07 acydburn Exp $
+* @version $Id$
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
@@ -87,7 +87,7 @@ $lang = array_merge($lang, array(
 	'AVATAR_NO_SIZE'				=> 'Не атрымалася вызначыць памеры паказанай аватары. Увядзіце іх уручную.',
 	'AVATAR_PARTIAL_UPLOAD'			=> 'Паказаны файл загружаны толькі часткова',
 	'AVATAR_PHP_SIZE_NA'			=> 'Занадта вялікі памер файла аватары.<br />Не атрымалася вызначыць максімальны памер, усталяваны ў php.ini.',
-	'AVATAR_PHP_SIZE_OVERRUN'		=> 'Занадта вялікі памер файла аватары. Максімальна дапушчальны памер — %d Мб.<br />Нататка: гэтае абмежаванне ўсталявана ў файле php.ini і не можа быць перавышана.',
+	'AVATAR_PHP_SIZE_OVERRUN'		=> 'Занадта вялікі памер файла аватары. Максімальна дапушчальны памер %1$d %2$s.<br />Нататка: гэтае абмежаванне ўсталявана ў файле php.ini і не можа быць перавышана.',
 	'AVATAR_URL_INVALID'			=> 'Паказаны адрас аватары недапушчальны.',
 	'AVATAR_URL_NOT_FOUND'			=> 'Паказаны файл аватары не знойдзены.',
 	'AVATAR_WRONG_FILESIZE'			=> 'Памер файла аватары павінен нахадзіцца ў дыяпазоне ад 0 да %1d %2s.',
@@ -160,6 +160,7 @@ $lang = array_merge($lang, array(
 	'EDIT_POST'							=> 'Рэдагаваць паведамленне',
 	'EMAIL'								=> 'Email',
 	'EMAIL_ADDRESS'						=> 'Адрас email',
+	'EMAIL_INVALID_EMAIL'				=> 'Уведзены няправільны адрас электроннай пошты.',
 	'EMAIL_SMTP_ERROR_RESPONSE'			=> 'Памылка пры адпраўцы email у <strong>радку %1$s</strong>. Адказ сервера: %2$s.',
 	'EMPTY_SUBJECT'						=> 'Пры стварэнні новай тэмы неабходна паказаць загаловак.',
 	'EMPTY_MESSAGE_SUBJECT'				=> 'Вы павінны паказаць тэму новага паведамлення.',
@@ -390,6 +391,7 @@ $lang = array_merge($lang, array(
 	'NO_POSTS_TIME_FRAME'		=> 'У тэме няма паведамленняў за вылучаны перыяд часу.',
 	'NO_FEED_ENABLED'			=> 'Каналы навін недаступныя на гэтай канферэнцыі.',
 	'NO_FEED'					=> 'Запытваемы канал навін недаступны.',
+	'NO_STYLE_DATA'				=> 'Не атрымалася атрымаць дадзеныя аб стылі.',
 	'NO_SUBJECT'				=> 'Не паказаная тэма',								// Used for posts having no subject defined but displayed within management pages.
 	'NO_SUCH_SEARCH_MODULE'		=> 'Паказаны пошукавы механізм адсутнічае.',
 	'NO_SUPPORTED_AUTH_METHODS'	=> 'Метад аўтэнтыфікацыі не падтрымліваецца.',
@@ -568,9 +570,11 @@ $lang = array_merge($lang, array(
 	'SUBJECT'					=> 'Загаловак',
 	'SUBMIT'					=> 'Адправіць',
 
+	'TB'				=> 'TB',
 	'TERMS_USE'			=> 'Агульныя правілы',
 	'TEST_CONNECTION'	=> 'Праверыць падлучэнне',
 	'THE_TEAM'			=> 'Наша каманда',
+	'TIB'				=> 'TiB',
 	'TIME'				=> 'Час',
 
 	'TOO_LARGE'						=> 'Уведзенае значэнне занадта вялікае.',
@@ -718,6 +722,7 @@ $lang = array_merge($lang, array(
 	'WHO_IS_ONLINE'		=> 'Хто зараз на канферэнцыі',
 	'WRONG_PASSWORD'	=> 'Вы ўвялі няслушны пароль.',
 
+	'WRONG_DATA_COLOUR'			=> 'Уведзена няправільнае значэнне колеру.',
 	'WRONG_DATA_ICQ'			=> 'Уведзены нумар не з\'яўляюцца правільным нумарам ICQ.',
 	'WRONG_DATA_JABBER'			=> 'Уведзенае імя не з\'яўляецца правільным імем Jabber.',
 	'WRONG_DATA_LANG'			=> 'Паказаны няправільная мова.',
