@@ -47,21 +47,21 @@ $lang = array_merge($lang, array(
 	'ATTACH_SIG'				=> 'Далучыць подпіс (подпіс можна змяняць у асабістым раздзеле)',
 
 	'BBCODE_A_HELP'				=> 'Уставіць укладанне ў тэкст паведамлення: [attachment=]filename.ext[/attachment]',
-	'BBCODE_B_HELP'				=> 'Тоўсты тэкст: [b]text[/b]',
+	'BBCODE_B_HELP'				=> 'Тлусты тэкст: [b]тэкст[/b]',
 	'BBCODE_C_HELP'				=> 'Код: [code]code[/code]',
 	'BBCODE_D_HELP'				=> 'Флэш: [flash=width,height]http://url[/flash]',
-	'BBCODE_F_HELP'				=> 'Памер шрыфта: [size=85]small text[/size]',
+	'BBCODE_F_HELP'				=> 'Памер шрыфта: [size=85]невялікі шрыфт[/size]',
 	'BBCODE_IS_OFF'				=> '%sBBCode%s <em>ВЫКЛЮЧАНЫ</em>',
 	'BBCODE_IS_ON'				=> '%sBBCode%s <em>УКЛЮЧАНЫ</em>',
-	'BBCODE_I_HELP'				=> 'Нахільны тэкст: [i]text[/i]',
-	'BBCODE_L_HELP'				=> 'Спіс: [list]text[/list]',
-	'BBCODE_LISTITEM_HELP'		=> 'Элемент спісу: [*]text[/*]',
-	'BBCODE_O_HELP'				=> 'Нумараваны спіс: [list=]text[/list]',
+	'BBCODE_I_HELP'				=> 'Нахільны тэкст: [i]тэкст[/i]',
+	'BBCODE_L_HELP'				=> 'Спіс: [list][*]тэкст[/list]',
+	'BBCODE_LISTITEM_HELP'		=> 'Элемент спісу: [*]тэкст',
+	'BBCODE_O_HELP'				=> 'Нумараваны спіс: [list=1][*]Першы пункт[/list] or [list=a][*]Пункт а[/list]',
 	'BBCODE_P_HELP'				=> 'Уставіць малюнак: [img]http://image_url[/img]',
-	'BBCODE_Q_HELP'				=> 'Цытата: [quote]text[/quote]',
-	'BBCODE_S_HELP'				=> 'Колер шрыфта: [color=red]text[/color] Парада: Вы можаце выкарыстаць таксама канструкцыю color=#FF0000',
-	'BBCODE_U_HELP'				=> 'Падкрэслены тэкст: [u]text[/u]',
-	'BBCODE_W_HELP'				=> 'Уставіць спасылку: [url]http://url[/url] або [url=http://url]URL text[/url]',
+	'BBCODE_Q_HELP'				=> 'Цытата: [quote]тэкст[/quote]',
+	'BBCODE_S_HELP'				=> 'Колер шрыфта: [color=red]тэкст[/color] Парада: Вы можаце выкарыстаць таксама канструкцыю color=#FF0000',
+	'BBCODE_U_HELP'				=> 'Падкрэслены тэкст: [u]тэкст[/u]',
+	'BBCODE_W_HELP'				=> 'Уставіць спасылку: [url]http://url[/url] або [url=http://url]URL тэкст[/url]',
 	'BBCODE_Y_HELP'				=> 'Спіс: дадаць элемент спісу',
 	'BUMP_ERROR'				=> 'Вы не можаце паднімаць тэму адразу пасля апошняга паведамлення. Паспрабуйце ледзь пазней.',
 
@@ -142,7 +142,7 @@ $lang = array_merge($lang, array(
 
 	'PARTIAL_UPLOAD'			=> 'Файл загружаны толькі часткова.',
 	'PHP_SIZE_NA'				=> 'Занадта вялікі памер укладання.<br />Немагчыма вызначыць максімальны памер запампаваных файлаў, зададзены ў php.ini.',
-	'PHP_SIZE_OVERRUN'			=> 'Занадта вялікі памер укладання.<br />Максімальны памер запампаванага файла: %d Мб.<br />Майце ў выгляду, што гэтая велічыня вызначаная ў php.ini і сродкамі форума немагчыма змяніць гэтае значэнне ў вялікі бок.',
+	'PHP_SIZE_OVERRUN'			=> 'Занадта вялікі памер укладання, максімальны памер запампаванага файла: %1$d %2$s.<br />Майце ў выгляду, што гэтая велічыня вызначана ў php.ini і сродкамі форума немагчыма змяніць гэтае значэнне.',
 	'PLACE_INLINE'				=> 'Уставіць у тэкст паведамлення',
 	'POLL_DELETE'				=> 'Выдаліць апытанне',
 	'POLL_FOR'					=> 'Апытанне павінен ісці',
@@ -219,7 +219,7 @@ $lang = array_merge($lang, array(
 	'VIEW_MESSAGE'				=> '%sПраглядзець ваша паведамленне%s',
 	'VIEW_PRIVATE_MESSAGE'		=> '%sПраглядзець адпраўленыя вамі асабістыя паведамленні%s',
 
-	'WRONG_FILESIZE'			=> 'Занадта вялікі памер укладання. <br/>Максімальны дазволены памер: %1d %2s.',
+	'WRONG_FILESIZE'			=> 'Занадта вялікі памер укладання, максімальны дазволены памер %1d %2s.',
 	'WRONG_SIZE'				=> 'Памеры малюнка павінны быць не меней %1$d?%2$d і не больш %3$d?%4$d. Памер адпраўленага малюнка - %5$d?%6$d. Усе памеры паказаныя ў піксэлах.',
 ));
 
